import React, { useEffect } from "react";
import Grid from "@mui/material/Grid";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import SessionsChart from "../SessionsChart/sessionChart";
import ResourcesPieChart from "../ResourcePieChart/resourcePieChart";
import RoundedBarChart from "../barChartCard/barChartCard";
import LineChartCard from "../LineChartCard/lineChartCard";
import { AppDispatch, RootState } from "../../redux/store/store";
import { useDispatch, useSelector } from "react-redux";
import { fetchDashboardData } from "../../redux/slices/dashboardSlice";
import AppTheme from "../../shared-theme/AppTheme";
import StatCard from "../StatCard/statCard";

export default function AdminGrid() {
	const dispatch = useDispatch<AppDispatch>();
	const { totalManagers, totalUsers, totalStations, loading, error } =
		useSelector((state: RootState) => state.dashboardReducer);

	useEffect(() => {
		dispatch(fetchDashboardData());
	}, [dispatch]);

	// Fallback defaults if data is undefined
	const data = {
		totalManagers: totalManagers ?? 12,
		totalUsers: totalUsers ?? 24,
		totalStations: totalStations ?? 8,
	};

	const statCards = [
		{ title: "Total Managers", value: data.totalManagers },
		{ title: "Total Users", value: data.totalUsers },
		{ title: "Total Stations", value: data.totalStations },
	];

	return (
		<AppTheme>
			<Box
				sx={{
					width: "100%",
					maxWidth: "1800px",
					mx: "auto",
					px: { xs: 2, sm: 1, md: 0 },
					background: (theme) => theme.palette.background.default,
				}}
			>
				{/* Header */}
				<Typography variant="h4" component="h2" sx={{ mb: 3 }}>
					Admin Dashboard
				</Typography>

				<Grid container spacing={3} justifyContent="center">
					{statCards.map((card, index) => (
						<Grid
							key={index}
							item
							xs={12}
							sm={6}
							md={
								statCards.length === 1
									? 12
									: statCards.length === 2
									? 6
									: 4
							}
							lg={
								statCards.length === 1
									? 12
									: statCards.length === 2
									? 6
									: 4
							}
							xl={
								statCards.length === 1
									? 8
									: statCards.length === 2
									? 6
									: 4
							}
						>
							<StatCard {...card} />
						</Grid>
					))}
				</Grid>

				{/* Charts */}
				<Grid container spacing={3} sx={{ mt: 1 }}>
					<Grid item xs={12} md={6}>
						<SessionsChart />
					</Grid>
					<Grid item xs={12} md={6}>
						<ResourcesPieChart />
					</Grid>
					<Grid item xs={12} md={6}>
						<RoundedBarChart />
					</Grid>
					<Grid item xs={12} md={6}>
						<LineChartCard />
					</Grid>
				</Grid>
			</Box>
		</AppTheme>
	);
}
