import React, { useEffect } from "react";
import Grid from "@mui/material/Grid";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import SessionsChart from "../SessionsChart/sessionChart";
import ResourcesPieChart from "../ResourcePieChart/resourcePieChart";
import RoundedBarChart from "../barChartCard/barChartCard";
import LineChartCard from "../LineChartCard/lineChartCard";
import { AppDispatch, RootState } from "../../redux/store/store";
import { useDispatch, useSelector } from "react-redux";
import { fetchDashboardData } from "../../redux/slices/dashboardSlice";
import AppTheme from "../../shared-theme/AppTheme";
import StatCard from "../StatCard/statCard";
import StaticLineChartCard from "../StaticLineChartCard/staticLineChartCard";
import StaticResourcePieChart from "../StaticResourcePieChart/staticResourceChart";
import UtilizationGaugeChart from "../UtilizationGaugeChart/utilizationGaugeChart";

export default function ManagerGrid() {
	const dispatch = useDispatch<AppDispatch>();
	const { totalUsers, totalStations } = useSelector(
		(state: RootState) => state.dashboardReducer
	);

	useEffect(() => {
		dispatch(fetchDashboardData());
	}, [dispatch]);

	const statCards = [{ title: "Total Users", value: totalUsers ?? 24 }];

	return (
		<AppTheme>
			<Box
				sx={{
					width: "100%",
					maxWidth: "1800px",
					mx: "auto",
					px: { xs: 2, sm: 2, md: 3 },
					background: (theme) => theme.palette.background.default,
				}}
			>
				{/* Header */}
				<Typography
					component="h2"
					variant="h4"
					sx={{ mb: 3, fontWeight: 600 }}
				>
					Dashboard
				</Typography>

				{/* Stat Cards - Centered */}
				<Grid
					container
					spacing={3}
					justifyContent="center"
					alignItems="stretch"
					sx={{ mb: 1 }}
				>
					{statCards.map((card, index) => (
						<Grid key={index} item xs={12} sm={12} md={6} lg={6}>
							<StatCard {...card} />
						</Grid>
					))}

					{/* Add the Utilization Chart */}
					<Grid item xs={12} sm={12} md={6} lg={6}>
						<UtilizationGaugeChart />
					</Grid>
				</Grid>

				{/* Charts */}
				<Grid container spacing={3} mt={1}>
					<Grid item xs={12} sm={12} md={6} lg={6}>
						<ResourcesPieChart />
					</Grid>
					<Grid item xs={12} sm={12} md={6} lg={6}>
						<StaticLineChartCard />
					</Grid>
					<Grid item xs={12} sm={12} md={6} lg={6}>
						<LineChartCard />
					</Grid>

					<Grid item xs={12} sm={12} md={6} lg={6}>
						<StaticResourcePieChart />
					</Grid>
				</Grid>
			</Box>
		</AppTheme>
	);
}
