import { Box, Button, Modal, Typography, Divider, Grid } from "@mui/material";
import { RootState } from "../../../redux/store/store";
import { useSelector } from "react-redux";
import { useEffect, useState } from "react";
import CloseIcon from "@mui/icons-material/Close";

type Props = {
	open: boolean;
	setViewModal: Function;
	handleView: (id: string | undefined) => void;
	id?: string;
};

const style = {
	position: "absolute",
	top: "50%",
	left: "50%",
	transform: "translate(-50%, -50%)",
	width: 400,
	borderRadius: 2,
	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
	p: 0,
	display: "flex",
	flexDirection: "column",
	alignItems: "center",
};

export default function ViewModal({ open, setViewModal, id }: Props) {
	const { admins } = useSelector((state: RootState) => state.adminReducer);
	const [selectedAdmin, setSelectedAdmin] = useState<any>(null);

	useEffect(() => {
		if (id) {
			const admin = admins.find((admin) => admin.id === id);
			setSelectedAdmin(admin);
		}
	}, [id, admins]);

	return (
		<Modal
			open={open}
			aria-labelledby="modal-title"
			aria-describedby="modal-description"
		>
			<Box sx={style}>
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
						backgroundColor: "#000000",
						color: "#D0E1E9",
						padding: "20px 24px",
						borderRadius: "10px 10px 0 0",
						width: "100%",
						boxSizing: "border-box",
					}}
				>
					<Typography
						id="modal-title"
						variant="h5"
						fontWeight="bold"
						sx={{ width: "100%" }}
					>
						<Box
							sx={{
								display: "flex",
								alignItems: "center",
								justifyContent: "space-between",
								width: "100%",
							}}
						>
							<Box
								sx={{
									flex: 1,
									textAlign: "center",
									color: "#D0E1E9",
								}}
							>
								{selectedAdmin?.name || "Admin"}'s Details
							</Box>
							<Box
								onClick={() => setViewModal(false)}
								sx={{
									cursor: "pointer",
									display: "flex",
									alignItems: "center",
									color: "#D0E1E9",
								}}
							>
								<CloseIcon />
							</Box>
						</Box>
					</Typography>
				</Box>
				{/* <Divider sx={{ width: "100%" }} /> */}
				<Box
					sx={{
						backgroundColor: "#b5c4cb",
						padding: "20px",
						borderRadius: "0 0 10px 10px", // Rounded bottom corners
					}}
				>
					{selectedAdmin ? (
						<Grid container spacing={3} sx={{ width: "100%" }}>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Name:</strong>
									<Typography variant="body2" color="#454545">
										{selectedAdmin.name}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Phone:</strong>
									<Typography variant="body2" color="#454545">
										{selectedAdmin.phone}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Email:</strong>
									<Typography variant="body2" color="#454545">
										{selectedAdmin.email}
									</Typography>
								</Typography>
							</Grid>
							<Grid item xs={6}>
								<Typography variant="body1" color="#000000">
									<strong>Address:</strong>

									<Typography variant="body2" color="#454545">
										{selectedAdmin?.Admins?.[0]
											?.registeredAddress ?? "N/A"}
									</Typography>
								</Typography>
							</Grid>
						</Grid>
					) : (
						<Typography align="center" color="#454545">
							No admin found with this ID
						</Typography>
					)}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							onClick={() => setViewModal(false)}
							sx={{
								backgroundColor: "#000000",
								color: "#D0E1E9",
								borderRadius: "8px",
								fontSize: "16px",
								width: "117px",
								"&:hover": { backgroundColor: "#454545" },
							}}
						>
							Close
						</Button>
					</Box>
				</Box>
			</Box>
		</Modal>
	);
}

// import {
// 	Box,
// 	Button,
// 	Modal,
// 	Typography,
// 	Tabs,
// 	Tab,
// 	Divider,
// 	Grid,
// } from "@mui/material";
// import { AppDispatch, RootState } from "../../../redux/store/store";
// import { useDispatch, useSelector } from "react-redux";
// import { useEffect, useState } from "react";
// import CloseIcon from "@mui/icons-material/Close";
// import { managerList } from "../../../redux/slices/managerSlice";
// import {
// 	AsyncThunkAction,
// 	ThunkDispatch,
// 	UnknownAction,
// } from "@reduxjs/toolkit";

// type Props = {
// 	open: boolean;
// 	setViewModal: Function;
// 	handleView: (id: string | undefined) => void;
// 	id?: string;
// };

// interface TabPanelProps {
// 	children?: React.ReactNode;
// 	index: number;
// 	value: number;
// }

// const style = {
// 	position: "absolute",
// 	top: "50%",
// 	left: "50%",
// 	transform: "translate(-50%, -50%)",
// 	width: 600,
// 	borderRadius: 2,
// 	boxShadow: "0px 4px 20px rgba(0, 0, 0, 0.15)",
// 	p: 0,
// 	display: "flex",
// 	flexDirection: "column",
// 	alignItems: "center",
// };

// function TabPanel(props: TabPanelProps) {
// 	const { children, value, index, ...other } = props;
// 	return (
// 		<div
// 			role="tabpanel"
// 			hidden={value !== index}
// 			id={`tabpanel-${index}`}
// 			aria-labelledby={`tab-${index}`}
// 			{...other}
// 		>
// 			{value === index && <Box sx={{ p: 3 }}>{children}</Box>}
// 		</div>
// 	);
// }

// export default function ViewModal({ open, setViewModal, id }: Props) {
// 	const { admins } = useSelector((state: RootState) => state.adminReducer);
// 	const { managers } = useSelector(
// 		(state: RootState) => state.managerReducer
// 	);
// 	const [selectedAdmin, setSelectedAdmin] = useState<any>(null);
// 	const selectedManager = managers.find(
// 		(manager) => String(manager.id) === String(selectedAdmin?.id)
// 	);

// 	const dispatch = useDispatch();

// 	const [tabValue, setTabValue] = useState(0);

// 	useEffect(() => {
// 		if (id) {
// 			const admin = admins.find((admin) => admin.id === id);
// 			setSelectedAdmin(admin);
// 		}
// 	}, [id, admins]);
// 	useEffect(() => {
// 		if (open) {
// 			//dispatch(managerList());
// 		}
// 	}, [open, dispatch]);
// 	const handleTabChange = (event: React.SyntheticEvent, newValue: number) => {
// 		setTabValue(newValue);
// 	};

// 	return (
// 		<Modal
// 			open={open}
// 			aria-labelledby="modal-title"
// 			aria-describedby="modal-description"
// 		>
// 			<Box sx={style}>
// 				<Box
// 					sx={{
// 						display: "flex",
// 						justifyContent: "space-between",
// 						alignItems: "center",
// 						backgroundColor: "#000000",
// 						color: "#D0E1E9",
// 						padding: "20px 24px",
// 						borderRadius: "10px 10px 0 0",
// 						width: "100%",
// 						boxSizing: "border-box",
// 					}}
// 				>
// 					<Typography
// 						id="modal-title"
// 						variant="h5"
// 						fontWeight="bold"
// 						sx={{ width: "100%" }}
// 					>
// 						<Box
// 							sx={{
// 								display: "flex",
// 								alignItems: "center",
// 								justifyContent: "space-between",
// 								width: "100%",
// 							}}
// 						>
// 							<Box
// 								sx={{
// 									flex: 1,
// 									textAlign: "center",
// 									color: "#D0E1E9",
// 								}}
// 							>
// 								{selectedAdmin?.name || "Admin"}'s Details
// 							</Box>
// 							<Box
// 								onClick={() => setViewModal(false)}
// 								sx={{
// 									cursor: "pointer",
// 									display: "flex",
// 									alignItems: "center",
// 									color: "#D0E1E9",
// 								}}
// 							>
// 								<CloseIcon />
// 							</Box>
// 						</Box>
// 					</Typography>
// 				</Box>

// 				<Box sx={{ width: "100%", backgroundColor: "#b5c4cb" }}>
// 					<Tabs
// 						value={tabValue}
// 						onChange={handleTabChange}
// 						aria-label="admin details tabs"
// 						sx={{
// 							backgroundColor: "#000000",
// 							"& .MuiTabs-indicator": {
// 								backgroundColor: "#D0E1E9",
// 							},
// 						}}
// 					>
// 						<Tab
// 							label="Admin Details"
// 							sx={{
// 								color: "#D0E1E9",
// 								"&.Mui-selected": { color: "#D0E1E9" },
// 							}}
// 						/>
// 						<Tab
// 							label="Manager Details"
// 							sx={{
// 								color: "#D0E1E9",
// 								"&.Mui-selected": { color: "#D0E1E9" },
// 							}}
// 						/>
// 						<Tab
// 							label="Charging Stations"
// 							sx={{
// 								color: "#D0E1E9",
// 								"&.Mui-selected": { color: "#D0E1E9" },
// 							}}
// 						/>
// 						<Tab
// 							label="User Details"
// 							sx={{
// 								color: "#D0E1E9",
// 								"&.Mui-selected": { color: "#D0E1E9" },
// 							}}
// 						/>
// 					</Tabs>

// 					<TabPanel value={tabValue} index={0}>
// 						{selectedAdmin ? (
// 							<Grid container spacing={3}>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Name:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedAdmin.name}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Phone:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedAdmin.phone}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Email:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedAdmin.email}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Address:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedAdmin?.Admins?.[0]
// 												?.registeredAddress ?? "N/A"}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 							</Grid>
// 						) : (
// 							<Typography align="center" color="#454545">
// 								No admin found with this ID
// 							</Typography>
// 						)}
// 					</TabPanel>

// 					<TabPanel value={tabValue} index={1}>
// 						{selectedManager ? (
// 							<Grid container spacing={3}>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Manager Name:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedManager.name ?? "N/A"}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Manager Email:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedManager.email ?? "N/A"}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Phone:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedManager.phone ?? "N/A"}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 								<Grid item xs={6}>
// 									<Typography variant="body1" color="#000000">
// 										<strong>Station Name:</strong>
// 										<Typography
// 											variant="body2"
// 											color="#454545"
// 										>
// 											{selectedManager.chargingStation
// 												?.name ?? "N/A"}
// 										</Typography>
// 									</Typography>
// 								</Grid>
// 							</Grid>
// 						) : (
// 							<Typography align="center" color="#454545">
// 								No manager details available
// 							</Typography>
// 						)}
// 					</TabPanel>

// 					<TabPanel value={tabValue} index={2}>
// 						{selectedAdmin?.chargingStations?.length > 0 ? (
// 							<Grid container spacing={3}>
// 								{selectedAdmin.chargingStations.map(
// 									(station: any, index: number) => (
// 										<Grid item xs={12} key={index}>
// 											<Typography
// 												variant="body1"
// 												color="#000000"
// 											>
// 												<strong>
// 													Station {index + 1}:
// 												</strong>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Name:{" "}
// 													{station.name ?? "N/A"}
// 												</Typography>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Location:{" "}
// 													{station.location ?? "N/A"}
// 												</Typography>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Status:{" "}
// 													{station.status ?? "N/A"}
// 												</Typography>
// 											</Typography>
// 											{index <
// 												selectedAdmin.chargingStations
// 													.length -
// 													1 && (
// 												<Divider sx={{ my: 2 }} />
// 											)}
// 										</Grid>
// 									)
// 								)}
// 							</Grid>
// 						) : (
// 							<Typography align="center" color="#454545">
// 								No charging stations assigned
// 							</Typography>
// 						)}
// 					</TabPanel>

// 					<TabPanel value={tabValue} index={3}>
// 						{selectedAdmin?.users?.length > 0 ? (
// 							<Grid container spacing={3}>
// 								{selectedAdmin.users.map(
// 									(user: any, index: number) => (
// 										<Grid item xs={12} key={index}>
// 											<Typography
// 												variant="body1"
// 												color="#000000"
// 											>
// 												<strong>
// 													User {index + 1}:
// 												</strong>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Name: {user.name ?? "N/A"}
// 												</Typography>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Email: {user.email ?? "N/A"}
// 												</Typography>
// 												<Typography
// 													variant="body2"
// 													color="#454545"
// 												>
// 													Role: {user.role ?? "N/A"}
// 												</Typography>
// 											</Typography>
// 											{index <
// 												selectedAdmin.users.length -
// 													1 && (
// 												<Divider sx={{ my: 2 }} />
// 											)}
// 										</Grid>
// 									)
// 								)}
// 							</Grid>
// 						) : (
// 							<Typography align="center" color="#454545">
// 								No users assigned
// 							</Typography>
// 						)}
// 					</TabPanel>

// 					<Box
// 						sx={{
// 							display: "flex",
// 							justifyContent: "flex-end",
// 							p: 2,
// 							borderRadius: "0 0 10px 10px",
// 						}}
// 					>
// 						<Button
// 							onClick={() => setViewModal(false)}
// 							sx={{
// 								backgroundColor: "#000000",
// 								color: "#D0E1E9",
// 								borderRadius: "8px",
// 								fontSize: "16px",
// 								width: "117px",
// 								"&:hover": { backgroundColor: "#454545" },
// 							}}
// 						>
// 							Close
// 						</Button>
// 					</Box>
// 				</Box>
// 			</Box>
// 		</Modal>
// 	);
// }
