import * as React from "react";
import { Box, CssBaseline, Typography } from "@mui/material";
import { useSelector } from "react-redux";
import { RootState } from "../../redux/store/store";

import {
	chartsCustomizations,
	dataGridCustomizations,
	datePickersCustomizations,
	treeViewCustomizations,
} from "./theme/customizations";

import AppTheme from "../../shared-theme/AppTheme";
import MainGrid from "../../components/MainGrid/mainGrid";
import AdminGrid from "../../components/MainGrid/adminGrid";
import ManagerGrid from "../../components/MainGrid/managerGrid";
import UserDashboard from "../../components/MainGrid/userDashboard";

const xThemeComponents = {
	...chartsCustomizations,
	...dataGridCustomizations,
	...datePickersCustomizations,
	...treeViewCustomizations,
};

interface DashboardProps {
	disableCustomTheme?: boolean;
}

const Dashboard: React.FC<DashboardProps> = ({
	disableCustomTheme = false,
}) => {
	
	const userType = useSelector(
		(state: RootState) => state.profileReducer.user?.userType
	);

	
	const renderGrid = () => {
		switch (userType?.toLowerCase()) {
			case "superadmin":
				return <MainGrid />;
			case "admin":
				return <AdminGrid />;
			case "manager":
				return <ManagerGrid />;
			case "user":
				return <UserDashboard />;

			default:
				return("")
				// return (
				// 	<Box
				// 		sx={{
				// 			display: "flex",
				// 			justifyContent: "center",
				// 			alignItems: "center",
				// 			backgroundColor: "#D0E1E9",
				// 			height: "100vh",
				// 			textAlign: "center",
				// 			padding: 2,
				// 		}}
				// 	>
				// 		<Typography color="black">
				// 			Access Denied: You do not have permission to view
				// 			this dashboard.
				// 		</Typography>
				// 	</Box>
				// );
		}
	};

	return (
		<AppTheme
			{...{ disableCustomTheme }}
			themeComponents={xThemeComponents}
		>
			<CssBaseline enableColorScheme />
			{!disableCustomTheme && renderGrid()}
		</AppTheme>
	);
};

export default Dashboard;
